# summary statistics
x <- rnorm(50)
mean(x); var(x); sd(x); median(x);
quantile(x)
IQR(x)
pvec <- seq(0,1,0.1); pvec
quantile(x,pvec)


#example from Dalgaard
library(ISwR)
attach(juul)
mean(igf1)
length(igf1)
sum(!is.na(igf1))
summary(igf1)
summary(juul)
#Graphical display of distributions
#Histograms
par(mfrow=c(2,1))
hist(x)
#Altman (1991, pp. 25-26)
mid.age <- c(2.5,7.5,13,16.5,17.5,19,22.5,44.5,70.5)
acc.count <- c(28,46,58,20,31,64,149,316,103)
age.acc <- rep(mid.age,acc.count)
brk <- c(0,5,10,16,17,18,20,25,60,80)
hist(age.acc,breaks=brk,col="lightblue")
par(mfrow=c(1,1))
#Empirical cumulative distribution
n <- length(x)
plot(sort(x),(1:n)/n,type="s",ylim=c(0,1))
plot.ecdf(x,verticals = TRUE, do.points = FALSE)
#Q-Q plots
qqnorm(x)
qqplot(x,rt(50,30),main="QQ-plot normal vs T")
qqline(x,distribution = function(x) qnorm(x),col=3)
#Box plots

par(mfrow=c(1,2))
boxplot(IgM)
boxplot(log(IgM))
par(mfrow=c(1,1))

#Summary statistics by groups
#The tapply call takes the folate variable, splits it according to
#ventilation, and computes the mean for each group. In the same way,
#standard deviations and the number of observations in the groups can be
#computed.
attach(red.cell.folate)
tapply(folate,ventilation,mean)
tapply(folate,ventilation,sd)
tapply(folate,ventilation,length)
#Try something like this for a nicer display:
xbar <- tapply(folate, ventilation, mean)
s <- tapply(folate, ventilation, sd)
n <- tapply(folate, ventilation, length)
cbind(mean=xbar, std.dev=s, n=n)
#For the juul data
tapply(igf1, tanner, mean)
tapply(igf1, tanner, mean, na.rm=T)
#Functions aggregate and by
aggregate(juul[c("age","igf1")],
      list(sex=juul$sex), mean, na.rm=T)
aggregate(juul[c("age","igf1")], juul["sex"], mean, na.rm=T)
by(juul, juul["sex"], summary)
#Graphics for grouped data
#Histogram
attach(energy)
expend.lean <- expend[stature=="lean"]
expend.obese <- expend[stature=="obese"]
par(mfrow=c(2,1))
hist(expend.lean,breaks=10,xlim=c(5,13),ylim=c(0,4),col="white")
hist(expend.obese,breaks=10,xlim=c(5,13),ylim=c(0,4),col="grey")
par(mfrow=c(1,1))
#Parallel boxplots
boxplot(expend ~ stature)
#almost equivalent
boxplot(expend.lean,expend.obese)
#Stripcharts
opar <- par(mfrow=c(2,2), mex=0.8, mar=c(3,3,2,1)+.1)
stripchart(expend ~ stature)
stripchart(expend ~ stature, method="stack")
stripchart(expend ~ stature, method="jitter")
stripchart(expend ~ stature, method="jitter", jitter=.03)
par(opar)

stripchart(list(lean=expend.lean, obese=expend.obese))

#Tables
#Generating tables
caff.marital <- matrix(c(652,1537,598,242,36,46,38,21,218
                     ,327,106,67),
                      nrow=3,byrow=T)
caff.marital
#Names for rows and columns
colnames(caff.marital) <- c("0","1-150","151-300",">300")
rownames(caff.marital) <- c("Married","Prev.married","Single")
caff.marital
as.data.frame(as.table(caff.marital))
#table, xtabs, or ftable applied to data set juul
table(sex)
table(sex,menarche)
table(menarche,tanner)
#The xtabs function is quite similar to table except that it uses a model
#formula interface.
xtabs(~ tanner + sex, data=juul)
xtabs(~ dgn + diab + coma, data=stroke)
#ftab flat tables
ftable(coma + diab ~ dgn, data=stroke)
t(caff.marital) #transposition

#Marginal tables and relative frequency
tanner.sex <- table(tanner,sex)
tanner.sex
#compute the marginal tables:
margin.table(tanner.sex,1)
margin.table(tanner.sex,2)
prop.table(tanner.sex,1)
tanner.sex/sum(tanner.sex)

#Graphical display of tables
#Barplots
total.caff <- margin.table(caff.marital,2)
total.caff
barplot(total.caff, col="white")

par(mfrow=c(2,2))
barplot(caff.marital, col="white")
barplot(t(caff.marital), col="white")
barplot(t(caff.marital), col="white", beside=T)
barplot(prop.table(t(caff.marital),2), col="white", beside=T)
par(mfrow=c(1,1))
#ways to "prettify" the plots
barplot(prop.table(t(caff.marital),2),beside=T,
         legend.text=colnames(caff.marital),
        col=c("white","grey80","grey50","black"))
#Dotcharts


#Piecharts
opar <- par(mfrow=c(2,2),mex=0.8, mar=c(1,1,2,1))
slices <- c("white","grey80","grey50","black")
pie(caff.marital["Married",], main="Married", col=slices)
pie(caff.marital["Prev.married",],
       main="Previously married", col=slices)
pie(caff.marital["Single",], main="Single", col=slices)
par(opar)
par(mfrow=c(1,1))